/*
 * Created by sweetbread
 * Copyright (c) 2025. All rights reserved.
 */

package ru.risdeveau.geotracker

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.Button
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontStyle
import androidx.compose.ui.text.style.TextDecoration
import androidx.compose.ui.unit.dp
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch
import org.intellij.lang.annotations.JdkConstants
import ru.risdeveau.geotracker.ui.theme.GeoTrackerTheme
import splitties.resources.appColor
import splitties.resources.appStr
import kotlin.apply

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            GeoTrackerTheme {
                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                    Box(
                        Modifier
                            .padding(innerPadding)
                            .fillMaxSize()) {
                        var screen by remember { mutableStateOf<Screen>(Screen.Loading) }

                        when (screen) {
                            Screen.Main -> TODO()

                            Screen.Settings -> {
                                Settings(Modifier.align(Alignment.Center))
                            }

                            Screen.Loading -> {
                                var loading by remember { mutableStateOf(true) }

                                if (loading) {
                                    CircularProgressIndicator(Modifier.align(Alignment.Center))
                                    LaunchedEffect(true) {
                                        launch {
                                            screen = if (health(SettingsPreferences.url))
                                                Screen.Main
                                            else
                                                Screen.Settings
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}

sealed class Screen {
    object Main : Screen()
    object Settings : Screen()
    object Loading : Screen()
}

@Composable
fun Settings(modifier: Modifier = Modifier) {
    var username by remember { mutableStateOf("") }
    var url by remember { mutableStateOf("") }
    var urlIsValid by remember { mutableStateOf(false) }
    var loading by remember { mutableStateOf(false) }

    LaunchedEffect(url) {
        if (url.isNotEmpty()) {
            delay(1000)
            loading = true
            urlIsValid = health(url)
            loading = false
        }
    }

    Column (modifier = modifier, horizontalAlignment = Alignment.CenterHorizontally) {
        OutlinedTextField(
            value = username,
            onValueChange = { username = it },
            label = { Text(appStr(R.string.username)) }
        )

        OutlinedTextField(
            value = url,
            onValueChange = { url = it },
            placeholder = { Text("https://geo.example.com", style = TextStyle(color = MaterialTheme.colorScheme.onSurfaceVariant)) },
            label = { Text(appStr(R.string.server_url)) },
            trailingIcon = { if (loading) CircularProgressIndicator() }
        )

        Button({}, enabled = urlIsValid) {
            Text(appStr(R.string.apply))
        }
    }
}